/*
 * Copyright 2008 Takao Sumitomo. All rights reserved.
 * 
 * Redistribution and use in source and binary forms,
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the 
 *      above copyright notice, this list of conditions
 *      and the following disclaimer.
 *   2. Redistributions in binary form must reproduce 
 *      the above copyright notice, this list of conditions
 *      and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software
 * and documentation are those of the authors and should not be
 * interpreted as representing official policies,
 * either expressed or implied.
 * 
 * @Author: Takao Sumitomo
 */
/*
 * 作成日: 2008/03/16
 */
package net.cattaka.converttosculpt.data;

public class BQuaternion4d
{
    public double w;
    public double x;
    public double y;
    public double z;
    
    public BQuaternion4d()
    {
    }
    
    /**
     * @param w
     * @param x
     * @param y
     * @param z
     */
    public BQuaternion4d(double w, double x, double y, double z)
    {
        super();
        this.w = w;
        this.x = x;
        this.y = y;
        this.z = z;
    }
    
    /**
     * Copy constructor.
     * @param src
     */
    public BQuaternion4d(BQuaternion4d src) {
        assert(src != null);
        
        set(src);
    }
    
    public void set(BQuaternion4d src) {
        assert(src != null);

        this.w = src.w;
        this.x = src.x;
        this.y = src.y;
        this.z = src.z;
    }
    
    public void negate() {
        this.x = - this.x;
        this.y = - this.y;
        this.z = - this.z;
    }
    
    /**
     * this = this * q
     * 
     * @param q
     */
    public void mul(BQuaternion4d q) {
        assert(q != null);
        double tw,tx,ty,tz;
        
        tw = this.w*q.w - this.x*q.x - this.y*q.y - this.z*q.z;
        tx = this.w*q.x + this.x*q.w + this.y*q.z - this.z*q.y;
        ty = this.w*q.y + this.y*q.w + this.z*q.x - this.x*q.z;
        tz = this.w*q.z + this.z*q.w + this.x*q.y - this.y*q.x;
        this.w = tw;
        this.x = tx;
        this.y = ty;
        this.z = tz;
    }
    
    /**
     * vec = this*vec
     * 
     * @param vec
     */
    public void rotate(BVector3d v) {
        assert(v != null);
        BQuaternion4d r = new BQuaternion4d(this);
        BQuaternion4d t = new BQuaternion4d(0, v.x, v.y, v.z);
        BQuaternion4d q = new BQuaternion4d(this);
        q.negate();

        r.mul(t);
        r.mul(q);
        
        v.x = r.x;
        v.y = r.y;
        v.z = r.z;
    }
    
    /**
     * 軸を中心に回転するクオータニオンを作成する。
     * 
     * @param n
     * @param angle
     */
    public void setAxisAngle(BVector3d axis, double angle) {
        assert(axis != null);
        if (axis.isZero()) {
            this.w = 1.0;
            this.x = 0.0;
            this.y = 0.0;
            this.z = 0.0;
        } else {
            BVector3d n = new BVector3d(axis);
            n.normalize();
            double c = Math.cos(angle / 2);
            double s = Math.sin(angle / 2);
            
            this.w = c;
            this.x = axis.x * s;
            this.y = axis.y * s;
            this.z = axis.z * s;
        }
    }
    @Override
    public String toString()
    {
        return "(" + w + ", " + x + ", " + y + ", " + z + ")";
    }
}
