/*
 * Copyright 2008 Takao Sumitomo. All rights reserved.
 * 
 * Redistribution and use in source and binary forms,
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the 
 *      above copyright notice, this list of conditions
 *      and the following disclaimer.
 *   2. Redistributions in binary form must reproduce 
 *      the above copyright notice, this list of conditions
 *      and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software
 * and documentation are those of the authors and should not be
 * interpreted as representing official policies,
 * either expressed or implied.
 * 
 * @Author: Takao Sumitomo
 */
/*
 * 作成日: 2008/02/16
 */
package net.cattaka.converttosculpt.data;

import java.io.Serializable;

/**
 * ３次元ベクトルを表すクラス。
 * 
 * @author cattaka
 */

public class BVector3d implements Serializable
{
    public double x;
    public double y;
    public double z;
    public BVector3d() {
    }
    
    /**
     * Copy constructor.
     * @param src
     */
    public BVector3d(BVector3d src) {
        this.x = src.x;
        this.y = src.y;
        this.z = src.z;
    }

    public BVector3d(double x, double y, double z) {
        this.x = x;
        this.y = y;
        this.z = z;
    }
    
    public void add(BVector3d v) {
        this.x += v.x;
        this.y += v.y;
        this.z += v.z;
    }

    public void sub(BVector3d v) {
        this.x -= v.x;
        this.y -= v.y;
        this.z -= v.z;
    }
    
    public void scale(double scale) {
        this.x *= scale;
        this.y *= scale;
        this.z *= scale;
    }

    /**
     * this = this + scale * v
     * @param scale
     * @param v
     */
    public void scaleAdd(double scale, BVector3d v) {
        this.x += scale * v.x;
        this.y += scale * v.y;
        this.z += scale * v.z;
    }
    
    public static double getDistance(BVector3d v1, BVector3d v2) {
        double x = v1.x - v2.x;
        double y = v1.y - v2.y;
        double z = v1.z - v2.z;
        return Math.sqrt(x*x + y*y + z*z);
    }
    
    public static void getCross(BVector3d dist, BVector3d v1, BVector3d v2) {
        dist.x = v1.y * v2.z - v1.z * v2.y;
        dist.y = v1.z * v2.x - v1.x * v2.z;
        dist.z = v1.x * v2.y - v1.y * v2.x;
    }
    
    public static double getDot(BVector3d v1, BVector3d v2) {
        return v1.x * v2.x + v1.y * v2.y + v1.z * v2.z; 
    }
    
    public boolean isZero() {
        return (x==0 && y == 0 && z == 0);
    }
    
    public double getLength() {
        return Math.sqrt(x*x + y*y + z*z);
    }
    public void normalize() {
        double l = getLength();
        this.x /= l;
        this.y /= l;
        this.z /= l;
    }
    
    public void set(BVector3d v) {
        this.x = v.x;
        this.y = v.y;
        this.z = v.z;
    }
    @Override
    public String toString()
    {
        return "(" + x + ", " + y + ", " + z + ")";
    }
}
