/*
 * Copyright 2008 Takao Sumitomo. All rights reserved.
 * 
 * Redistribution and use in source and binary forms,
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the 
 *      above copyright notice, this list of conditions
 *      and the following disclaimer.
 *   2. Redistributions in binary form must reproduce 
 *      the above copyright notice, this list of conditions
 *      and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software
 * and documentation are those of the authors and should not be
 * interpreted as representing official policies,
 * either expressed or implied.
 * 
 * @Author: Takao Sumitomo
 */
/*
 * 作成日: Feb 16, 2008
 */
package net.cattaka.converttosculpt.logic;

/**
 * レンダリングにおける設定情報を持つクラス。
 * スカルプテクスチャの頂点数と、実際のイメージ情報を保持する。
 * 
 * @author cattaka
 */
public class RenderingConf
{
    public static final int DEFAULT_VERTEX_NUM_X = 33;
    public static final int DEFAULT_VERTEX_NUM_Y = 33;
    public static final int DEFAULT_IMAGE_WIDTH = 64;
    public static final int DEFAULT_IMAGE_HEIGHT = 64;
    
    private int vertexNumX;
    private int vertexNumY;
    private int imageWidth;
    private int imageHeight;

    public RenderingConf() {
        this.vertexNumX = DEFAULT_VERTEX_NUM_X;
        this.vertexNumY = DEFAULT_VERTEX_NUM_Y;
        this.imageWidth = DEFAULT_IMAGE_WIDTH;
        this.imageHeight = DEFAULT_IMAGE_HEIGHT;
    }

    public RenderingConf(RenderingConf src) {
        this.vertexNumX = src.getVertexNumX();
        this.vertexNumY = src.getVertexNumY();
        this.imageWidth = src.getImageWidth();
        this.imageHeight = src.getImageHeight();
    }
    
    public int getVertexNumX()
    {
        return vertexNumX;
    }

    public void setVertexNumX(int vertexNumX)
    {
        this.vertexNumX = vertexNumX;
    }

    public int getVertexNumY()
    {
        return vertexNumY;
    }

    public void setVertexNumY(int vertexNumY)
    {
        this.vertexNumY = vertexNumY;
    }

    public int getImageWidth()
    {
        return imageWidth;
    }

    public void setImageWidth(int imageWidth)
    {
        this.imageWidth = imageWidth;
    }

    public int getImageHeight()
    {
        return imageHeight;
    }

    public void setImageHeight(int imageHeight)
    {
        this.imageHeight = imageHeight;
    }

    
}
