/*
 * Copyright 2008 Takao Sumitomo. All rights reserved.
 * 
 * Redistribution and use in source and binary forms,
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the 
 *      above copyright notice, this list of conditions
 *      and the following disclaimer.
 *   2. Redistributions in binary form must reproduce 
 *      the above copyright notice, this list of conditions
 *      and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software
 * and documentation are those of the authors and should not be
 * interpreted as representing official policies,
 * either expressed or implied.
 * 
 * @Author: Takao Sumitomo
 */
/*
 * 作成日: 2008/03/15
 */
package net.cattaka.converttosculpt.logic;

import java.util.ArrayList;

import net.cattaka.converttosculpt.exception.InvalidStructureException;

public class StringUtil
{
    public static String stripChars(String src, String headChars, String tailChars) {
        int startPos = 0;
        int endPos = src.length()-1;
        if (headChars.length() > 0) {
            for (startPos = 0;startPos <src.length();startPos++) {
                if (headChars.indexOf(src.charAt(startPos)) == -1) {
                    break;
                }
            }
        }
        if (tailChars.length() > 0) {
            for (endPos = src.length()-1;endPos >=0;endPos--) {
                if (tailChars.indexOf(src.charAt(endPos)) == -1) {
                    break;
                }
            }
        }
        
        if (startPos >= endPos) {
            return "";
        } else {
            return src.substring(startPos, endPos+1);
        }
    }
    
    /**
     * テキストを走査し、目標となるエレメントのブレース(大括弧)で囲まれた文字列を得る。
     * 入れ子の内容も含む。
     * 
     * @param src
     * @param elementName
     * @return
     */
    public static ArrayList<String> getElementString(String src, String elementName, char startBrace, char endBrace) {
        ArrayList<String> result = new ArrayList<String>();
        
        int ch = 0;
        while ((ch = src.indexOf(elementName, ch)) != -1) {
            String t = getBracedString(src, ch, startBrace, endBrace);
            if (t != null) {
                result.add(t);
            } else {
                throw new InvalidStructureException("Unknown excepton.");
            }
            ch += 1;
        }
        
        return result;
    }
    
    public static String getBracedString(String src, int p, char startBrace, char endBrace) {
        int startPos = -1;
        int endPos = -1;
        int braceCount = 0;
        for (int i=p;i<src.length();i++) {
            if (src.charAt(i) == startBrace) {
                if (braceCount == 0) {
                    startPos = i+1;
                }
                braceCount++;
            }
            if (src.charAt(i) == endBrace) {
                braceCount--;
                if (braceCount == 0) {
                    endPos = i;
                    break;
                }
            }
        }
        if (startPos == -1 || endPos == -1) {
            throw new InvalidStructureException("Could not pair of brace.");
        } else {
            return src.substring(startPos, endPos);
        }
    }
    
    /**
     * テキストを走査し、目標となるエレメントの開始地点からブレース(大括弧)の終わりまでの文字列を得る。
     * 入れ子の内容も含む。
     * 
     * @param src
     * @param elementName
     * @return
     */
    public static ArrayList<String> getElementFullString(String src, String elementName, char startBrace, char endBrace) {
        ArrayList<String> result = new ArrayList<String>();
        
        int ch = 0;
        while ((ch = src.indexOf(elementName, ch)) != -1) {
            String t = getBracedFullString(src, ch, startBrace, endBrace);
            if (t != null) {
                result.add(t);
            } else {
                throw new InvalidStructureException("Unknown excepton.");
            }
            ch += 1;
        }
        
        return result;
    }

    public static String getBracedFullString(String src, int p, char startBrace, char endBrace) {
        int startPos = -1;
        int endPos = -1;
        int braceCount = 0;
        for (int i=p;i<src.length();i++) {
            if (src.charAt(i) == startBrace) {
                if (braceCount == 0) {
                    startPos = i+1;
                }
                braceCount++;
            }
            if (src.charAt(i) == endBrace) {
                braceCount--;
                if (braceCount == 0) {
                    endPos = i;
                    break;
                }
            }
        }
        if (startPos == -1 || endPos == -1) {
            throw new InvalidStructureException("Could not pair of brace.");
        } else {
            return src.substring(p, endPos+1);
        }
    }
}
