/*
 * Copyright 2008 Takao Sumitomo. All rights reserved.
 * 
 * Redistribution and use in source and binary forms,
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the 
 *      above copyright notice, this list of conditions
 *      and the following disclaimer.
 *   2. Redistributions in binary form must reproduce 
 *      the above copyright notice, this list of conditions
 *      and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software
 * and documentation are those of the authors and should not be
 * interpreted as representing official policies,
 * either expressed or implied.
 * 
 * @Author: Takao Sumitomo
 */
/*
 * 作成日: 2008/03/13
 */
package net.cattaka.converttosculpt.logic;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.w3c.dom.DOMImplementation;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.SAXParseException;

public class XMLConverter
{
    public static Element readXML(URL url)
    throws IOException,SAXParseException
    {
        URLConnection uc = url.openConnection();
        InputStream in = uc.getInputStream();
        Element el = readXML(in);
        in.close();
        return el;
    }
 
    public static Element readXML(File file)
    throws IOException,SAXParseException
    {
        try
        {
            Document document= DocumentBuilderFactory.newInstance()
                .newDocumentBuilder().parse(file);
            return document.getDocumentElement();
        }catch(Exception e)
        {
            throw new IOException("XMLConverter:Invalid file:"+ file);
        }
    }
    
    public static Element readXML(InputStream in)
    throws IOException,SAXParseException
    {
        try
        {
            Document document= DocumentBuilderFactory.newInstance()
                .newDocumentBuilder().parse(in);
            return document.getDocumentElement();
        }catch(Exception e)
        {
            //e.printStackTrace();
            throw new IOException("XMLConverter:InputStream error");
        }
    }

    
    public static void writeXML(File file,Document document) throws IOException
    {
        try
        {
            TransformerFactory transFactory = TransformerFactory.newInstance();
            Transformer transformer = transFactory.newTransformer();
            
            DOMSource source = new DOMSource(document);
            FileOutputStream out = new FileOutputStream(file); 
            StreamResult result = new StreamResult(out); 
            transformer.transform(source, result);
            
            out.close();
        }catch(Exception e)
        {
            throw new IOException(e.toString());
        }
    }

    /**
     * 新しいXMLドキュメントを作成する。
     * 
     * @param qualifiedName
     * @return
     */
    public static Document createNewDocument(String qualifiedName)
    {
        try
        {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            DocumentBuilder builder = factory.newDocumentBuilder();         
            DOMImplementation domImpl=builder.getDOMImplementation();
            return domImpl.createDocument("",qualifiedName,null);
        }catch(Exception e)
        {
            throw new RuntimeException("createNewDocument:" + e.toString());
        }
    }

}
