/*
 * Copyright 2008 Takao Sumitomo. All rights reserved.
 * 
 * Redistribution and use in source and binary forms,
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the 
 *      above copyright notice, this list of conditions
 *      and the following disclaimer.
 *   2. Redistributions in binary form must reproduce 
 *      the above copyright notice, this list of conditions
 *      and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software
 * and documentation are those of the authors and should not be
 * interpreted as representing official policies,
 * either expressed or implied.
 * 
 * @Author: Takao Sumitomo
 */

/*
 * 作成日: Feb 16, 2008
 */
package net.cattaka.converttosculpt.ui;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;

import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import net.cattaka.converttosculpt.logic.VersionBundle;

public class ConvertToSculptFrame extends JFrame implements ActionListener
{
    public static final int GRID_SIZE = 32;
    
    private JFileChooser fileChooser;
    private HelpPanel helpPanel;
    private HelpPanel licensePanel;
    
    public ConvertToSculptFrame()
    {
        initialize();
    }
    
    private void initialize() {
        setTitle("ConvertToSculpt" + " build " + VersionBundle.getBuildNumber());
        this.fileChooser = new JFileChooser();
        {
            URL helpUrl = this.getClass().getClassLoader().getResource("help.utf8.txt");
            if (helpUrl != null) {
                this.helpPanel = new HelpPanel("Help",helpUrl);
            }
            
            URL licenseUrl = this.getClass().getClassLoader().getResource("license.txt");
            if (licenseUrl != null) {
                this.licensePanel = new HelpPanel("License", licenseUrl);
            }
        }
        //Create menubar
        JMenuBar menuBar = new JMenuBar();
        JMenu helpMenu = new JMenu("Help");
        JMenuItem licenseMenuItem = new JMenuItem("lisence");
        JMenuItem helpMenuItem = new JMenuItem("help");
        licenseMenuItem.setActionCommand("license");
        licenseMenuItem.addActionListener(this);
        helpMenuItem.setActionCommand("help");
        helpMenuItem.addActionListener(this);
        helpMenu.add(licenseMenuItem);
        helpMenu.add(helpMenuItem);
        menuBar.add(helpMenu);
        this.setJMenuBar(menuBar);
        
        ConvertToSculptPanel convertToSculptPanel = new ConvertToSculptPanel(this.fileChooser);
        this.getContentPane().add(convertToSculptPanel);
        
        
    }
    

    public void actionPerformed(ActionEvent e)
    {
        try {
            if (e.getActionCommand().equals("license")) {
                licensePanel.setVisible(true);
            } else if (e.getActionCommand().equals("help")) {
                helpPanel.setVisible(true);
            } else if (e.getActionCommand().equals("exit")) {
                this.setVisible(false);
            }
        } catch (Exception ex) {
            JOptionPane.showMessageDialog(this, ex.getMessage());
            ex.printStackTrace();
        }
    }
    
    public static void main(String[] args)
    {
        ConvertToSculptFrame f = new ConvertToSculptFrame();
        f.setSize(600, 550);
        f.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        
        f.setVisible(true);
    }
}
