/*
 * Copyright 2008 Takao Sumitomo. All rights reserved.
 * 
 * Redistribution and use in source and binary forms,
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the 
 *      above copyright notice, this list of conditions
 *      and the following disclaimer.
 *   2. Redistributions in binary form must reproduce 
 *      the above copyright notice, this list of conditions
 *      and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software
 * and documentation are those of the authors and should not be
 * interpreted as representing official policies,
 * either expressed or implied.
 * 
 * @Author: Takao Sumitomo
 */

package net.cattaka.converttosculpt.ui;
import javax.swing.JViewport;
import java.awt.image.BufferedImage;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Dimension;

/**
 * 画像を表示するためのパネル。
 * このバージョンはスクロール機能は削除されて、
 * 拡大縮小しながらパネル上に画像をレンダリングする。
 * 
 * @author cattaka
 *
 */
public class GraphView extends JViewport
{
    private BufferedImage image;

    public void paint(Graphics g)
    {
        int w = getWidth();
        int h = getHeight();
        if(image != null)
        {
            if (w > h) {
                w = h;
            } else {
                h = w;
            }
            
            g.drawImage(image,0,0, w, h, this);
        } else {
            g.setColor(Color.BLACK);
            g.fillRect(0,0,w,h);
        }
        
    }

    public void setImage(BufferedImage image)
    {
        this.image = image;
//        if (image != null)
//        {
//            Dimension dim = new Dimension();
//            dim.height = image.getHeight();
//            dim.width = image.getWidth();
//            setPreferredSize(dim);
//            setSize(dim);
//        }
    }
    public BufferedImage getImage()
    {
        return image;
    }
    @Override
    public Dimension getPreferredSize()
    {
//        if (this.image != null)
//        {
//            Dimension dim = new Dimension();
//            dim.height = image.getHeight();
//            dim.width = image.getWidth();
//            return dim;
//        }
        return super.getPreferredSize();
    }
}
