/*
 * Copyright 2008 Takao Sumitomo. All rights reserved.
 * 
 * Redistribution and use in source and binary forms,
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the 
 *      above copyright notice, this list of conditions
 *      and the following disclaimer.
 *   2. Redistributions in binary form must reproduce 
 *      the above copyright notice, this list of conditions
 *      and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software
 * and documentation are those of the authors and should not be
 * interpreted as representing official policies,
 * either expressed or implied.
 * 
 * @Author: Takao Sumitomo
 */
/*
 * 作成日: 2008/03/10
 */
package net.cattaka.converttosculpt.ui;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.cattaka.converttosculpt.data.SizeInfo;



/**
 * SizeInfoを入力するためのパネル。
 * Auto normalizeが入ってるときはnullを返す。
 * 
 * @author cattaka
 */
public class InputSizeInfoPanel extends JPanel
{
    private SizeInfo sizeInfo;
    private JCheckBox checkEnableAuto;
    private JTextField fieldMinX;
    private JTextField fieldMaxX;
    private JTextField fieldMinY;
    private JTextField fieldMaxY;
    private JTextField fieldMinZ;
    private JTextField fieldMaxZ;
    
    public InputSizeInfoPanel() {
        makeLayout();
        
        this.sizeInfo = new SizeInfo();
        this.sizeInfo.setMinX(-1.0);
        this.sizeInfo.setMaxX( 1.0);
        this.sizeInfo.setMinY(-1.0);
        this.sizeInfo.setMaxY( 1.0);
        this.sizeInfo.setMinZ(-1.0);
        this.sizeInfo.setMaxZ( 1.0);
        this.updateFields();
    }
    
    private void makeLayout() {
        this.checkEnableAuto = new JCheckBox("Enable auto normalize");
        this.checkEnableAuto.setSelected(true);
        this.checkEnableAuto.addItemListener(new ItemListener(){
           public void itemStateChanged(ItemEvent e)
           {
               InputSizeInfoPanel.this.updateFields();
           } 
        });
        
        this.fieldMinX = new JTextField();
        this.fieldMaxX = new JTextField();
        this.fieldMinY = new JTextField();
        this.fieldMaxY = new JTextField();
        this.fieldMinZ = new JTextField();
        this.fieldMaxZ = new JTextField();
        
        JLabel labelSizeInfo = new JLabel("Normalize option");
        JLabel labelMinX = new JLabel("Min X");
        JLabel labelMaxX = new JLabel("Max X");
        JLabel labelMinY = new JLabel("Min Y");
        JLabel labelMaxY = new JLabel("Max Y");
        JLabel labelMinZ = new JLabel("Min Z");
        JLabel labelMaxZ = new JLabel("Max Z");

        GridBagLayout gbl = new GridBagLayout();
        GridBagConstraints gbc = new GridBagConstraints();
        
        gbc.fill = GridBagConstraints.HORIZONTAL;
        gbc.weightx = 0.0;
        gbc.weighty = 0.0;
        gbc.gridx = 0;
        gbc.gridy = 0;
        
        gbc.gridwidth = 4;
        gbc.anchor = GridBagConstraints.WEST;
        gbl.setConstraints(labelSizeInfo, gbc);
        gbc.gridy++;
        gbl.setConstraints(this.checkEnableAuto, gbc);
        gbc.gridy++;
        
        gbc.gridwidth = 1;

        gbl.setConstraints(labelMinX, gbc);
        gbc.gridy++;
        gbl.setConstraints(labelMinY, gbc);
        gbc.gridy++;
        gbl.setConstraints(labelMinZ, gbc);
        gbc.gridy-=2;
        gbc.gridx+=2;
        gbl.setConstraints(labelMaxX, gbc);
        gbc.gridy++;
        gbl.setConstraints(labelMaxY, gbc);
        gbc.gridy++;
        gbl.setConstraints(labelMaxZ, gbc);
        gbc.gridy-=2;
        gbc.gridx-=1;
        
        
        gbc.weightx = 1.0;
        gbl.setConstraints(this.fieldMinX, gbc);
        gbc.gridy++;
        gbl.setConstraints(this.fieldMinY, gbc);
        gbc.gridy++;
        gbl.setConstraints(this.fieldMinZ, gbc);
        gbc.gridy-=2;
        gbc.gridx+=2;
        gbl.setConstraints(this.fieldMaxX, gbc);
        gbc.gridy++;
        gbl.setConstraints(this.fieldMaxY, gbc);
        gbc.gridy++;
        gbl.setConstraints(this.fieldMaxZ, gbc);
        
        
        setLayout(gbl);
        add(labelSizeInfo);
        add(this.checkEnableAuto);
        add(labelMinX);
        add(labelMaxX);
        add(labelMinY);
        add(labelMaxY);
        add(labelMinZ);
        add(labelMaxZ);
        add(this.fieldMinX);
        add(this.fieldMaxX);
        add(this.fieldMinY);
        add(this.fieldMaxY);
        add(this.fieldMinZ);
        add(this.fieldMaxZ);
    }
    
    /**
     * 
     * @param src
     */
    public void setSizeInfo(SizeInfo src) {
        if (src == null) {
            throw new NullPointerException();
        }
        
        this.sizeInfo.set(src);
        this.updateFields();
    }
    
    private void updateFields() {
        this.fieldMinX.setText(String.valueOf(this.sizeInfo.getMinX()));
        this.fieldMaxX.setText(String.valueOf(this.sizeInfo.getMaxX()));
        this.fieldMinY.setText(String.valueOf(this.sizeInfo.getMinY()));
        this.fieldMaxY.setText(String.valueOf(this.sizeInfo.getMaxY()));
        this.fieldMinZ.setText(String.valueOf(this.sizeInfo.getMinZ()));
        this.fieldMaxZ.setText(String.valueOf(this.sizeInfo.getMaxZ()));
        
        boolean f = !(this.checkEnableAuto.isSelected());
        this.fieldMinX.setEnabled(f);
        this.fieldMaxX.setEnabled(f);
        this.fieldMinY.setEnabled(f);
        this.fieldMaxY.setEnabled(f);
        this.fieldMinZ.setEnabled(f);
        this.fieldMaxZ.setEnabled(f);
    }
    
    private void updateValues() throws NumberFormatException {
        double minX;
        double minY;
        double minZ;
        double maxX;
        double maxY;
        double maxZ;
    
        minX = Double.parseDouble(this.fieldMinX.getText());
        maxX = Double.parseDouble(this.fieldMaxX.getText());
        minY = Double.parseDouble(this.fieldMinY.getText());
        maxY = Double.parseDouble(this.fieldMaxY.getText());
        minZ = Double.parseDouble(this.fieldMinZ.getText());
        maxZ = Double.parseDouble(this.fieldMaxZ.getText());
        
        this.sizeInfo.setMinX(minX);
        this.sizeInfo.setMaxX(maxX);
        this.sizeInfo.setMinY(minY);
        this.sizeInfo.setMaxY(maxY);
        this.sizeInfo.setMinZ(minZ);
        this.sizeInfo.setMaxZ(maxZ);
    }
    
    /**
     * 
     * @return
     */
    public SizeInfo getSizeInfo() throws NumberFormatException {
        if (this.checkEnableAuto.isSelected()) {
            return null;
        } else {
            this.updateValues();
            return new SizeInfo(this.sizeInfo);
        }
    }
}
