/*
 * Copyright 2008 Takao Sumitomo. All rights reserved.
 * 
 * Redistribution and use in source and binary forms,
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the 
 *      above copyright notice, this list of conditions
 *      and the following disclaimer.
 *   2. Redistributions in binary form must reproduce 
 *      the above copyright notice, this list of conditions
 *      and the following disclaimer in the documentation
 *      and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software
 * and documentation are those of the authors and should not be
 * interpreted as representing official policies,
 * either expressed or implied.
 * 
 * @Author: Takao Sumitomo
 */
/*
 * 作成日: 2008/03/15
 */
package net.cattaka.converttosculpt.ui;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.cattaka.converttosculpt.data.BVector3d;


public class InputVector3dPanel extends JPanel
{
    private JCheckBox checkDisableOption;
    private JTextField fieldX;
    private JTextField fieldY;
    private JTextField fieldZ;
    private BVector3d vector3d;
    
    public InputVector3dPanel(String title, String strDisableOption)
    {
        this.vector3d = new BVector3d();
        makeLayout(title, strDisableOption);
        updateFieldsEnable();
    }
    private void makeLayout(String title, String strDisableOption) {
        this.fieldX = new JTextField();
        this.fieldY = new JTextField();
        this.fieldZ = new JTextField();
        JLabel labelTitle = new JLabel(title);
        JLabel labelFieldX = new JLabel("X");
        JLabel labelFieldY = new JLabel("Y");
        JLabel labelFieldZ = new JLabel("Z");
        this.checkDisableOption = new JCheckBox(strDisableOption);
        this.checkDisableOption.setSelected(true);
        this.checkDisableOption.addItemListener(new ItemListener(){
            public void itemStateChanged(ItemEvent e)
            {
                updateFieldsEnable();
            }
        });
        
        GridBagLayout gbl = new GridBagLayout();
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.fill = GridBagConstraints.HORIZONTAL;
        gbc.gridx = 0;
        gbc.gridy = 0;
        
        gbc.gridwidth = 2;
        gbl.setConstraints(labelTitle, gbc);
        gbc.gridy++;
        gbl.setConstraints(checkDisableOption, gbc);
        gbc.gridy++;
        
        gbc.gridwidth = 1;
        gbl.setConstraints(labelFieldX, gbc);
        gbc.gridy++;
        gbl.setConstraints(labelFieldY, gbc);
        gbc.gridy++;
        gbl.setConstraints(labelFieldZ, gbc);
        gbc.gridy++;
        
        gbc.weightx = 1.0;
        gbc.gridx++;
        gbc.gridy -= 3;
        gbl.setConstraints(fieldX, gbc);
        gbc.gridy++;
        gbl.setConstraints(fieldY, gbc);
        gbc.gridy++;
        gbl.setConstraints(fieldZ, gbc);
        gbc.gridy++;
        
        setLayout(gbl);
        add(labelTitle);
        add(checkDisableOption);
        add(labelFieldX);
        add(labelFieldY);
        add(labelFieldZ);
        add(fieldX);
        add(fieldY);
        add(fieldZ);
        
        resetFields();
    }
    
    private void updateFieldsEnable() {
        boolean f = !checkDisableOption.isSelected();
        this.fieldX.setEditable(f);
        this.fieldY.setEditable(f);
        this.fieldZ.setEditable(f);
    }
    
    private void resetFields() {
        this.fieldX.setText(String.valueOf(this.vector3d.x));
        this.fieldY.setText(String.valueOf(this.vector3d.y));
        this.fieldZ.setText(String.valueOf(this.vector3d.z));
    }
    public void setVector3d(BVector3d src) {
        this.vector3d.set(src);
    }
    public BVector3d getVector3d() {
        if (checkDisableOption.isSelected()) {
            return null;
        }
        double x,y,z;
        try {
            x = Double.parseDouble(fieldX.getText());
            y = Double.parseDouble(fieldY.getText());
            z = Double.parseDouble(fieldZ.getText());
        } catch (NumberFormatException e) {
            //this.resetFields();
            throw new NumberFormatException("Inputed data is invalid.");
        }
        this.vector3d.x = x;
        this.vector3d.y = y;
        this.vector3d.z = z;
        this.resetFields();
        return new BVector3d(this.vector3d);
    }
}
